@@ -33,6 +33,7 @@ from webob.exc import HTTPMethodNotAllowed
 from webob.exc import HTTPNotFound
 from webob.exc import HTTPRequestEntityTooLarge
 from webob.exc import HTTPServiceUnavailable
+from webob.exc import HTTPUnauthorized
 from webob import Response
 
 from glance.api import common
@@ -374,6 +375,8 @@ class Controller(controller.BaseController):
                 self._enforce_read_protected_props(image, req)
         except exception.Invalid as e:
             raise HTTPBadRequest(explanation=e.msg, request=req)
+        except exception.NotAuthenticated as e:
+            raise HTTPUnauthorized(explanation=e.msg, request=req)
         return dict(images=images)
 
     def _get_query_params(self, req):
@@ -934,9 +937,11 @@ class Controller(controller.BaseController):
             # Once an image is 'active' only an admin can
             # modify certain core metadata keys
             for key in ACTIVE_IMMUTABLE:
-                if (orig_status == 'active' and image_meta.get(key) is not None
+                if ((orig_status == 'active' or orig_status == 'deactivated')
+                        and image_meta.get(key) is not None
                         and image_meta.get(key) != orig_image_meta.get(key)):
-                    msg = _("Forbidden to modify '%s' of active image.") % key
+                    msg = _("Forbidden to modify '%(key)s' of %(status)s "
+                            "image.") % {'key': key, 'status': orig_status}
                     raise HTTPForbidden(explanation=msg,
                                         request=req,
                                         content_type="text/plain")
